@@ -1,8 +1,10 @@
+from curvenote.latex.utils.links import minimise_oxa_path
+from curvenote.latex.utils.regex import REF_COMMAND_OXA_REGEX
+from curvenote.latex.utils.index import LocalMarker
+import re
 import logging
+from .utils import LocalReferenceItem
 from typing import List, Optional, Union
-
-from curvenote.latex import utils
-
 from ..client import Session
 from ..models import Block, BlockFormat, BlockKind, BlockVersion, ChildrenList, Project
 from . import utils
@@ -29,6 +31,7 @@ class LatexArticle:
         self.content: str = ""
         # TODO obvious one to centralise in project or someway
         self.users = []
+        logging.info("created article")
 
     @property
     def title(self):
@@ -100,33 +103,55 @@ class LatexArticle:
             f"Processing Article: {self.version.id.project}/"
             f"{self.version.id.block}/versions/{self.version.id.version}"
         )
+        logging.info("fetch complete")
 
     def localize(
         self,
         session: Session,
         assets_folder: str,
-        reference_list: List[utils.LocalReferenceItem],
+        reference_list: List[LocalReferenceItem],
+        figure_list: List[LocalMarker],
     ):
-        """Parse article content and pull assets to local storage
+        """
+            Parse article content, pull assets to local storage and make usable local
+            references/labels available to commands as needed
 
         - images
         - authors
         - citations
+        - href
 
         TODO: this is turning into a double dispatchy thing, maybe article just holds a
         reference to the project
         """
-        logging.info("Localizing referenced content")
         self._localize_authors(session)
-        logging.info("Localized authors")
-        self._localize_content(session, assets_folder, reference_list)
-        logging.info("Localized content and references")
+        self._localize_content(session, assets_folder, reference_list, figure_list)
+
+    def reconcile_figures(self, figure_list: List[LocalMarker]):
+        """
+            For each register figure replace any references found in the content with
+        """
+        logging.info("reconciling figure refs")
+        all_refs = re.findall(REF_COMMAND_OXA_REGEX, self.content)
+        for ref_path in all_refs:
+            min_ref_path = minimise_oxa_path(ref_path)
+            figures = [f for f in figure_list if f.remote_path == min_ref_path]
+            if len(figures) == 0:
+                logger.info("Could not reconcile reference with oxa %s", ref_path)
+                # TODO null the ref - invalid latex
+                continue
+            logging.info("patching ref %s using min ref %s", ref_path, min_ref_path)
+            logging.info(f"\\ref{{{ref_path}}}")
+            logging.info(f"\\ref{{{figures[0].marker}}}")
+            self.content = self.content.replace(
+                f"\\ref{{{ref_path}}}", f"\\ref{{{figures[0].marker}}}")
 
     def write(self, filepath: str):
         with open(filepath, "w+") as file:
             file.write(self.content)
 
     def _localize_authors(self, session: Session):
+        logging.info("Localized authors")
         for author in self.authors:
             if author.user is not None:
                 try:
@@ -136,22 +161,28 @@ class LatexArticle:
                     continue
 
     def _localize_content(
-        self, session: Session, assets_folder: str, reference_list: List[str]
+        self,
+        session: Session,
+        assets_folder: str,
+        reference_list: List[str],
+        figure_list: List[str],
     ):
         """
         Ignores blocks of any type other than Content and Output.
         """
+        logging.info("Localized content and references")
         concatenated_content = ""
         for i, child in enumerate(self.children):
+            # pylint: disable=broad-except
             block = LatexBlockVersion(session, child)
 
             try:
-                block.localize(assets_folder, reference_list)
+                block.localize(assets_folder, reference_list, figure_list)
                 if i == 0:
                     concatenated_content += f"{block.content}\n"
                 else:
                     concatenated_content += f"\n\n{block.content}\n"
-            except ValueError:
+            except Exception:
                 continue
 
         self.content = concatenated_content
