@@ -1,14 +1,13 @@
-from typing import Union
-from curvenote.models import Project
 import logging
 import os
-from shutil import copyfile
 import pkg_resources
-
+from typing import Union, List
+from curvenote.models import Project
+from shutil import copyfile
 from jinja2 import Environment, PackageLoader
-
 from ..client import Session
 from .article import LatexArticle
+from .utils.index import LocalReferenceItem, LocalMarker
 
 logger = logging.getLogger()
 
@@ -21,12 +20,16 @@ class LatexProject:
         self.assets_folder = os.path.join(self.target_folder, "assets")
         self.images_folder = os.path.join(self.target_folder, "assets", "images")
         self.documents_folder = os.path.join(self.target_folder, "documents")
+
         logger.info(f"Creating {self.images_folder}")
         os.makedirs(self.images_folder, exist_ok=True)
         logger.info(f"Creating {self.documents_folder}")
         os.makedirs(self.documents_folder, exist_ok=True)
+
         self.articles = []
-        self.reference_list = []
+        self.reference_list: List[LocalReferenceItem] = []
+        self.figure_list: List[LocalMarker] = []
+
         self.jinja = None
         self._configure_jinja()
 
@@ -40,21 +43,9 @@ class LatexProject:
         version: int,
     ):
         latex_project = cls(session, target_folder)
-        try:
-            latex_project.add_article(project_id, article_id, version)
-        except ValueError as err:
-            logging.error(f"Error: {str(err)}")
-            raise ValueError(
-                f"Could not add article to LaTeX project: {str(err)}"
-            ) from err
-
-        try:
-            logging.info(f"writing to {target_folder}")
-            latex_project.write()
-        except ValueError as err:
-            logging.error(f"Error: {str(err)}")
-            logging.error(f"Could not write final document")
-            raise ValueError(f"Could not write final document") from err
+        latex_project.add_article(project_id, article_id, version)
+        latex_project.reconcile()
+        latex_project.write()
 
     def _configure_jinja(self):
         """
@@ -80,32 +71,40 @@ class LatexProject:
         self, project_id: Union[str, Project], article_id: str, version: int
     ):
         logging.info("add_article")
-        latex_article = LatexArticle(self.session, project_id, article_id)
-        logging.info("created article")
-        latex_article.fetch(version)
-        logging.info("fetch complete")
-        latex_article.localize(self.session, self.assets_folder, self.reference_list)
-        logging.info("localize complete")
+        # TODO decorators for try / catch :facepalm:
+        try:
+            latex_article = LatexArticle(self.session, project_id, article_id)
+            latex_article.fetch(version)
+            latex_article.localize(self.session, self.assets_folder, self.reference_list, self.figure_list)
 
-        idx = len(self.articles)
-        logging.info(f"number of articles {idx}")
-        filename = f"{idx}_{latex_article.block.name}"
-        logging.info(f"generate filename {filename}")
-        self.articles.append((f"documents/{filename}", latex_article, filename))
-        logging.info(f"appended article documents/{filename}")
+            filename = f"{len(self.articles)}_{latex_article.block.name}"
+            logging.info("generate filename %s", filename)
+
+            self.articles.append((f"documents/{filename}", latex_article, filename))
+            logging.info("appended article documents/%s", filename)
+
+        except ValueError as err:
+            logging.error("Error: %s", str(err))
+            raise ValueError(
+                f"Could not add article to LaTeX project: {str(err)}"
+            ) from err
+
+    def reconcile(self):
+        for article in self.articles:
+            article[1].reconcile_figures(self.figure_list)
 
     def render(self):
         template_assets = ["curvenote_paper.sty", "logo-horizontal-dark.png"]
-        logging.info(f"Copying template assets")
+        logging.info("Copying template assets")
         for asset in template_assets:
             src = pkg_resources.resource_filename(
                 "curvenote", f"{self.default_template_folder}/{asset}"
             )
             dest = os.path.join(self.target_folder, asset)
-            logging.info(f"Copying: {asset} to {dest}")
+            logging.info("Copying: %s to %s", asset, dest)
             copyfile(src, dest)
 
-        logging.info(f"Rendering template...")
+        logging.info("Rendering template...")
         template = self.jinja.get_template("index.tpl.tex")
         try:
             _, first_article, __ = self.articles[0]
@@ -122,21 +121,27 @@ class LatexProject:
             raise ValueError("Need at least one article") from err
 
     def write(self):
-        logging.info(f"Writing articles...")
-        for (_, article, filename) in self.articles:
-            article_filepath = os.path.join(self.documents_folder, filename + ".tex")
-            article.write(article_filepath)
+        logging.info("writing to %s", self.target_folder)
+        logging.info("Writing articles...")
+        try:
+            for (_, article, filename) in self.articles:
+                article_filepath = os.path.join(self.documents_folder, filename + ".tex")
+                article.write(article_filepath)
 
-        content = self.render()
+            content = self.render()
 
-        logging.info(f"Writing index.tex...")
-        with open(os.path.join(self.target_folder, "index.tex"), "w+") as file:
-            file.write(content)
+            logging.info("Writing index.tex...")
+            with open(os.path.join(self.target_folder, "index.tex"), "w+") as file:
+                file.write(content)
 
-        logging.info(f"Writing main.bib...")
-        if len(self.reference_list) > 0:
-            with open(os.path.join(self.target_folder, "main.bib"), "w+") as file:
-                for reference in self.reference_list:
-                    file.write(f"{reference.bibtex}\n")
+            logging.info("Writing main.bib...")
+            if len(self.reference_list) > 0:
+                with open(os.path.join(self.target_folder, "main.bib"), "w+") as file:
+                    for reference in self.reference_list:
+                        file.write(f"{reference.bibtex}\n")
 
-        logging.info(f"Done!")
+            logging.info("Done!")
+        except ValueError as err:
+            logging.error("Error: %", str(err))
+            logging.error("Could not write final document")
+            raise ValueError("Could not write final document") from err
