@@ -6,14 +6,14 @@ import requests
 
 from ...client import Session
 from ...models import BlockFormat, BlockVersion
-from .index import block_hash_to_url
+from .links import oxa_path_to_api_url
 from .localize_images import ImageFormats
 
 
 def get_image_block(
-    session: Session, assets_folder: str, block_path: str, local_path: str
+    session: Session, assets_folder: str, oxa_path: str, local_path: str
 ):
-    url = block_hash_to_url(session.api_url, block_path, BlockFormat.tex)
+    url = oxa_path_to_api_url(session.api_url, oxa_path, BlockFormat.tex)
     logging.info("fetching image block from %s", url)
     image_block = session._get_model(url, BlockVersion)
     if not image_block:
@@ -43,7 +43,7 @@ def get_image_block(
         logging.info("Found image/gif converting to image/png")
         # convert to png, leave gif file in place but return the png path for use in content
         local_path_with_extension = convert_gif(assets_folder, local_path_with_extension)
-        logging.info(f"Updated local path: {local_path_with_extension}")
+        logging.info("Updated local path: %s" % local_path_with_extension)
         # either calls will raise exception on error causing file to be skipped
 
     return image_block, local_path_with_extension
