@@ -2,7 +2,7 @@ from datetime import datetime
 from enum import Enum
 from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
 
-from pydantic import AnyHttpUrl, BaseModel
+from pydantic import AnyHttpUrl, BaseModel, constr
 from pydantic.generics import GenericModel
 
 
@@ -15,13 +15,13 @@ class ListLinks(SelfLinks):
 
 
 class UserLinks(SelfLinks):
-    photo: AnyHttpUrl
+    photo: Union[AnyHttpUrl, constr(max_length=0)] # url or empty str
 
 
 class MyUserLinks(UserLinks):
     projects: AnyHttpUrl
-    banner: Optional[AnyHttpUrl]
     access: AnyHttpUrl
+    banner: Optional[AnyHttpUrl]
 
 
 class User(BaseModel):
@@ -101,8 +101,20 @@ class BlockKind(str, Enum):
 
 
 class BlockID(BaseModel):
-    project: str
-    block: str
+    project: str = ...
+    block: str = ...
+
+class VersionID(BlockID):
+    version: int
+
+class SrcID(VersionID):
+    draft: str
+
+class PathSpec(BaseModel):
+    team: str
+    project: Optional[str]
+    block: Optional[str]
+    version: Optional[int]
 
 
 class BlockLinks(SelfLinks):
